@@ -6,21 +6,19 @@ import sys
 import tempfile
 import warnings
 
+from josepy import util as jose_util
 import pkg_resources
 import zope.interface
 
-from josepy import util as jose_util
-
 from acme.magic_typing import List  # pylint: disable=unused-import, no-name-in-module
-
 from certbot import achallenges  # pylint: disable=unused-import
-from certbot._internal import constants
 from certbot import crypto_util
 from certbot import errors
 from certbot import interfaces
 from certbot import reverter
-from certbot.compat import os
+from certbot._internal import constants
 from certbot.compat import filesystem
+from certbot.compat import os
 from certbot.plugins.storage import PluginStorage
 
 logger = logging.getLogger(__name__)
@@ -35,6 +33,7 @@ def dest_namespace(name):
     """ArgumentParser dest namespace (prefix of all destinations)."""
     return name.replace("-", "_") + "_"
 
+
 private_ips_regex = re.compile(
     r"(^127\.0\.0\.1)|(^10\.)|(^172\.1[6-9]\.)|"
     r"(^172\.2[0-9]\.)|(^172\.3[0-1]\.)|(^192\.168\.)")
@@ -296,7 +295,7 @@ class Addr(object):
                 # appended to the end
                 append_to_end = True
                 continue
-            elif len(block) > 1:
+            if len(block) > 1:
                 # remove leading zeros
                 block = block.lstrip("0")
             if not append_to_end:
@@ -375,9 +374,9 @@ def install_version_controlled_file(dest_path, digest_path, src_path, all_hashes
     active_file_digest = crypto_util.sha256sum(dest_path)
     if active_file_digest == current_hash: # already up to date
         return
-    elif active_file_digest in all_hashes: # safe to update
+    if active_file_digest in all_hashes: # safe to update
         _install_current_file()
-    else: # has been manually modified, not safe to update
+    else:  # has been manually modified, not safe to update
         # did they modify the current version or an old version?
         if os.path.isfile(digest_path):
             with open(digest_path, "r") as f:
